.. _pydl.photoop:

===================================
SDSS Imaging Data  (`pydl.photoop`)
===================================

Introduction
++++++++++++

This is a placeholder for photoop documentation.

API
+++

.. automodapi:: pydl.photoop
    :no-inheritance-diagram:

.. automodapi:: pydl.photoop.photoobj
    :no-inheritance-diagram:

.. automodapi:: pydl.photoop.sdssio
    :no-inheritance-diagram:

.. automodapi:: pydl.photoop.window
    :no-inheritance-diagram:
